@@ -32,19 +32,25 @@ managed_packages = ['snapper']
 name = _('Storage Snapshots')
 
 description = [
-    _('Snapshots allows creating and managing filesystem snapshots. These can '
-      'be used to roll back the system to a previously known good state in '
-      'case of unwanted changes to the system.'),
-    _('Automatic snapshots are taken every hour, day, month and year. '
-      'Although snapshots are efficient and only store the '
+    _('Snapshots allows creating and managing btrfs file system snapshots. '
+      'These can be used to roll back the system to a previously known '
+      'good state in case of unwanted changes to the system.'),
+    _('Snapshots are taken every hour, day and month (called timeline '
+      'snapshots). Snapshots are also taken before and after a software '
+      'installation. Although snapshots are efficient and only store the '
       'differences, they may be deleted to reclaim free space.  Individual '
       'files from older snapshots can be accessed by visiting "/.snapshots" '
-      'directory in the filesystem. Snapshots are not a replacement for '
-      'backups.')
+      'directory in the filesystem. It is recommended to enable snapshots '
+      'only if you have at least 50% free space on your root partition.'),
+    _('Snapshots work on btrfs file systems only and on the root '
+      'partition only. Snapshots are not a replacement for backups since '
+      'they are stored on the same partition. ')
 ]
 
 service = None
 
+manual_page = 'Snapshots'
+
 
 def init():
     """Initialize the module."""
